CREATE TABLE M_USER(
	user_id	bigint		Not Null		,
	user_name	text		Not Null		,
	user_password	text		Not Null		,
	user_grant	int		Not Null		,
	client_id	bigint		Not Null		,
	CONSTRAINT M_USER_PK1 PRIMARY KEY (user_id)
);

COMMENT ON COLUMN M_USER.user_id IS 'ユーザID';
COMMENT ON COLUMN M_USER.user_name IS 'ユーザ名';
COMMENT ON COLUMN M_USER.user_password IS 'パスワード';
COMMENT ON COLUMN M_USER.user_grant IS 'ユーザ権限 (0:ユーザ, 9:管理者)';
COMMENT ON COLUMN M_USER.client_id IS 'クライアントID';
CREATE TABLE M_CLIENT_GROUP(
	client_group_id	bigint		Not Null		,
	client_group_name	text		Not Null		,
	delete_flag	int		Not Null		,
	CONSTRAINT M_CLIENT_GROUP_PK1 PRIMARY KEY (client_group_id)
);

COMMENT ON COLUMN M_CLIENT_GROUP.client_group_id IS 'クライアントグループID';
COMMENT ON COLUMN M_CLIENT_GROUP.client_group_name IS 'クライアントグループ名';
COMMENT ON COLUMN M_CLIENT_GROUP.delete_flag IS '削除フラグ';
CREATE TABLE M_CLIENT(
	client_id	bigint		Not Null		,
	client_name	text		Not Null		,
	client_group_id	bigint		Not Null		,
	delete_flag	int		Not Null		,
	CONSTRAINT M_CLIENT_PK1 PRIMARY KEY (client_id)
);

COMMENT ON COLUMN M_CLIENT.client_id IS 'クライアントID';
COMMENT ON COLUMN M_CLIENT.client_name IS 'クライアント名';
COMMENT ON COLUMN M_CLIENT.client_group_id IS 'クライアントグループID (外部キーは張らない)';
COMMENT ON COLUMN M_CLIENT.delete_flag IS '削除フラグ';
CREATE TABLE M_GROUP(
	group_id	bigint		Not Null		,
	group_name	text		Not Null		,
	client_id	bigint		Not Null		REFERENCES M_CLIENT(client_id),
	delete_flag	int		Not Null		,
	CONSTRAINT M_GROUP_PK1 PRIMARY KEY (group_id)
);

COMMENT ON COLUMN M_GROUP.group_id IS 'グループID';
COMMENT ON COLUMN M_GROUP.group_name IS 'グループ名';
COMMENT ON COLUMN M_GROUP.client_id IS 'クライアントID';
COMMENT ON COLUMN M_GROUP.delete_flag IS '削除フラグ';
CREATE TABLE M_VIEWER(
	viewer_id	bigint		Not Null		,
	viewer_name	text		Not Null		,
	viewer_address	varchar (15)		Not Null		,
	client_id	bigint		Not Null		,
	group_id	bigint		Not Null		REFERENCES M_GROUP(group_id),
	status	int		Not Null		,
	delete_flag	int		Not Null		,
	CONSTRAINT M_VIEWER_PK1 PRIMARY KEY (viewer_id)
);

COMMENT ON COLUMN M_VIEWER.viewer_id IS 'ビューワID';
COMMENT ON COLUMN M_VIEWER.viewer_name IS 'ビューワ名';
COMMENT ON COLUMN M_VIEWER.viewer_address IS 'ビューワIPアドレス';
COMMENT ON COLUMN M_VIEWER.client_id IS 'クライアントID';
COMMENT ON COLUMN M_VIEWER.group_id IS 'グループID';
COMMENT ON COLUMN M_VIEWER.status IS 'ステータス (運用中:1　停止中：0)';
COMMENT ON COLUMN M_VIEWER.delete_flag IS '削除フラグ';
CREATE TABLE D_PROGRAM(
	program_id	bigint		Not Null		,
	program_name	text		Not Null		,
	client_id	bigint		Not Null		REFERENCES M_CLIENT(client_id),
	interrupt_flag	int		Not Null		,
	emergency_flag	int		Not Null		,
	stop_flag	int		Not Null		,
	random_flag	int		Not Null		,
	CONSTRAINT D_PROGRAM_PK1 PRIMARY KEY (program_id)
);

COMMENT ON COLUMN D_PROGRAM.program_id IS '番組ID';
COMMENT ON COLUMN D_PROGRAM.program_name IS '番組名';
COMMENT ON COLUMN D_PROGRAM.client_id IS 'クライアントID (番組は、作成したクライアントでのみ編集可能)';
COMMENT ON COLUMN D_PROGRAM.interrupt_flag IS '割込みフラグ';
COMMENT ON COLUMN D_PROGRAM.emergency_flag IS '緊急割込みフラグ';
COMMENT ON COLUMN D_PROGRAM.stop_flag IS '停止フラグ';
COMMENT ON COLUMN D_PROGRAM.random_flag IS 'ランダム再生フラグ';
CREATE TABLE D_PROGRAM_SCHEDULE(
	program_schedule_id	bigint		Not Null		,
	program_id	bigint		Not Null		REFERENCES D_PROGRAM(program_id),
	client_id	bigint		Not Null		REFERENCES M_CLIENT(client_id),
	start_date	timestamp		Not Null		,
	end_date	timestamp		Not Null		,
	start_time	timestamp		Not Null		,
	end_time	timestamp		Not Null		,
	sunday	int		Not Null		,
	monday	int		Not Null		,
	tuesday	int		Not Null		,
	wednesday	int		Not Null		,
	thursday	int		Not Null		,
	friday	int		Not Null		,
	saturday	int		Not Null		,
	priority	int				,
	CONSTRAINT D_PROGRAM_SCHEDULE_PK1 PRIMARY KEY (program_schedule_id)
);

COMMENT ON COLUMN D_PROGRAM_SCHEDULE.program_schedule_id IS '番組スケジュールID';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.program_id IS '番組ID';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.client_id IS 'クライアントID';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.start_date IS '開始日付';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.end_date IS '終了日付';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.start_time IS '開始時刻';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.end_time IS '終了時刻';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.sunday IS '日曜日';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.monday IS '月曜日';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.tuesday IS '火曜日';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.wednesday IS '水曜日';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.thursday IS '木曜日';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.friday IS '金曜日';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.saturday IS '土曜日';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE.priority IS '優先度 (1(優先) ～ 5（劣後）)';
CREATE TABLE D_PLAYLOG(
	playlog_id	bigint		Not Null		,
	client_id	bigint		Not Null		,
	viewer_id	bigint		Not Null		,
	program_name	text		Not Null		,
	content_data	text		Not Null		,
	start_time	timestamp		Not Null		,
	end_time	timestamp		Not Null		,
	play_seconds	int		Not Null		,
	CONSTRAINT D_PLAYLOG_PK1 PRIMARY KEY (playlog_id)
);

COMMENT ON COLUMN D_PLAYLOG.playlog_id IS '再生ログID';
COMMENT ON COLUMN D_PLAYLOG.client_id IS 'クライアントID';
COMMENT ON COLUMN D_PLAYLOG.viewer_id IS 'ビューワID';
COMMENT ON COLUMN D_PLAYLOG.program_name IS '番組名';
COMMENT ON COLUMN D_PLAYLOG.content_data IS 'コンテンツデータ';
COMMENT ON COLUMN D_PLAYLOG.start_time IS '開始時刻';
COMMENT ON COLUMN D_PLAYLOG.end_time IS '終了時刻';
COMMENT ON COLUMN D_PLAYLOG.play_seconds IS '再生時間';
CREATE TABLE D_PROGRAM_SCHEDULE_DAY(
	program_schedule_id	bigint		Not Null		REFERENCES D_PROGRAM_SCHEDULE(program_schedule_id),
	schedule_date	timestamp		Not Null		,
	CONSTRAINT D_PROGRAM_SCHEDULE_DAY_PK1 PRIMARY KEY (program_schedule_id, schedule_date)
);

COMMENT ON COLUMN D_PROGRAM_SCHEDULE_DAY.program_schedule_id IS '番組スケジュールID';
COMMENT ON COLUMN D_PROGRAM_SCHEDULE_DAY.schedule_date IS 'スケジュール日';
CREATE TABLE L_PROGRAM_SCHEDULE_VIEWER(
	program_schedule_id	bigint		Not Null		REFERENCES D_PROGRAM_SCHEDULE(program_schedule_id),
	viewer_id	bigint		Not Null		REFERENCES M_VIEWER(viewer_id),
	CONSTRAINT L_PROGRAM_SCHEDULE_VIEWER_PK1 PRIMARY KEY (program_schedule_id, viewer_id)
);

COMMENT ON COLUMN L_PROGRAM_SCHEDULE_VIEWER.program_schedule_id IS '番組スケジュールID';
COMMENT ON COLUMN L_PROGRAM_SCHEDULE_VIEWER.viewer_id IS 'ビューワID';
CREATE TABLE D_TELOP(
	telop_id	bigint		Not Null		,
	telop_name	text		Not Null		,
	client_id	bigint		Not Null		REFERENCES M_CLIENT(client_id),
	telop_text	text		Not Null		,
	font_name	text		Not Null		,
	font_size	int		Not Null		,
	back_color	int		Not Null		,
	font_color	int		Not Null		,
	scroll_speed	int		Not Null		,
	interrupt_flag	int		Not Null		,
	blink_flag	int		Not Null		,
	CONSTRAINT D_TELOP_PK1 PRIMARY KEY (telop_id)
);

COMMENT ON COLUMN D_TELOP.telop_id IS 'テロップID';
COMMENT ON COLUMN D_TELOP.telop_name IS 'テロップ名';
COMMENT ON COLUMN D_TELOP.client_id IS 'クライアントID';
COMMENT ON COLUMN D_TELOP.telop_text IS 'テロップテキスト';
COMMENT ON COLUMN D_TELOP.font_name IS 'フォント名';
COMMENT ON COLUMN D_TELOP.font_size IS 'フォントサイズ';
COMMENT ON COLUMN D_TELOP.back_color IS '背景色';
COMMENT ON COLUMN D_TELOP.font_color IS 'フォント色';
COMMENT ON COLUMN D_TELOP.scroll_speed IS 'スクロールスピード';
COMMENT ON COLUMN D_TELOP.interrupt_flag IS '割込みフラグ (0 : 通常番組, 1 : 割込番組, 2:緊急番組)';
COMMENT ON COLUMN D_TELOP.blink_flag IS '点滅フラグ';
CREATE TABLE D_TELOP_SCHEDULE(
	telop_schedule_id	bigint		Not Null		,
	telop_id	bigint		Not Null		REFERENCES D_TELOP(telop_id),
	client_id	bigint		Not Null		REFERENCES M_CLIENT(client_id),
	start_date	timestamp		Not Null		,
	end_date	timestamp		Not Null		,
	start_time	timestamp		Not Null		,
	end_time	timestamp		Not Null		,
	telop_align	int		Not Null		,
	sunday	int		Not Null		,
	monday	int		Not Null		,
	tuesday	int		Not Null		,
	wednesday	int		Not Null		,
	thursday	int		Not Null		,
	friday	int		Not Null		,
	saturday	int		Not Null		,
	priority	int		Not Null		,
	CONSTRAINT D_TELOP_SCHEDULE_PK1 PRIMARY KEY (telop_schedule_id)
);

COMMENT ON COLUMN D_TELOP_SCHEDULE.telop_schedule_id IS 'テロップスケジュールID';
COMMENT ON COLUMN D_TELOP_SCHEDULE.telop_id IS 'テロップID';
COMMENT ON COLUMN D_TELOP_SCHEDULE.client_id IS 'クライアントID';
COMMENT ON COLUMN D_TELOP_SCHEDULE.start_date IS '開始日付';
COMMENT ON COLUMN D_TELOP_SCHEDULE.end_date IS '終了日付';
COMMENT ON COLUMN D_TELOP_SCHEDULE.start_time IS '開始時刻';
COMMENT ON COLUMN D_TELOP_SCHEDULE.end_time IS '終了時刻';
COMMENT ON COLUMN D_TELOP_SCHEDULE.telop_align IS 'テロップ表示位置 (0: 下, 1:中, 2,上)';
COMMENT ON COLUMN D_TELOP_SCHEDULE.sunday IS '日曜日';
COMMENT ON COLUMN D_TELOP_SCHEDULE.monday IS '月曜日';
COMMENT ON COLUMN D_TELOP_SCHEDULE.tuesday IS '火曜日';
COMMENT ON COLUMN D_TELOP_SCHEDULE.wednesday IS '水曜日';
COMMENT ON COLUMN D_TELOP_SCHEDULE.thursday IS '木曜日';
COMMENT ON COLUMN D_TELOP_SCHEDULE.friday IS '金曜日';
COMMENT ON COLUMN D_TELOP_SCHEDULE.saturday IS '土曜日';
COMMENT ON COLUMN D_TELOP_SCHEDULE.priority IS '優先度 (1(優先) ～ 5（劣後）)';
CREATE TABLE D_TELOP_SCHEDULE_DAY(
	telop_schedule_id	bigint		Not Null		REFERENCES D_TELOP_SCHEDULE(telop_schedule_id),
	schedule_date	timestamp		Not Null		,
	CONSTRAINT D_TELOP_SCHEDULE_DAY_PK1 PRIMARY KEY (telop_schedule_id, schedule_date)
);

COMMENT ON COLUMN D_TELOP_SCHEDULE_DAY.telop_schedule_id IS 'テロップスケジュールID';
COMMENT ON COLUMN D_TELOP_SCHEDULE_DAY.schedule_date IS 'スケジュール日';
CREATE TABLE L_TELOP_SCHEDULE_VIEWER(
	telop_schedule_id	bigint		Not Null		REFERENCES D_TELOP_SCHEDULE(telop_schedule_id),
	viewer_id	bigint		Not Null		REFERENCES M_VIEWER(viewer_id),
	CONSTRAINT L_TELOP_SCHEDULE_VIEWER_PK1 PRIMARY KEY (telop_schedule_id, viewer_id)
);

COMMENT ON COLUMN L_TELOP_SCHEDULE_VIEWER.telop_schedule_id IS 'テロップスケジュールID';
COMMENT ON COLUMN L_TELOP_SCHEDULE_VIEWER.viewer_id IS 'ビューワID';
CREATE TABLE D_CONTENT(
	content_id	bigint		Not Null		,
	program_id	bigint		Not Null		REFERENCES D_PROGRAM(program_id),
	content_kind_id	int		Not Null		,
	content_playtime	int		Not Null		,
	content_order	int		Not Null		,
	content_data_1	text				,
	content_data_2	text				,
	content_data_3	text				,
	content_data_4	text				,
	content_data_5	text				,
	CONSTRAINT D_CONTENT_PK1 PRIMARY KEY (content_id)
);

COMMENT ON COLUMN D_CONTENT.content_id IS 'コンテンツID';
COMMENT ON COLUMN D_CONTENT.program_id IS '番組ID';
COMMENT ON COLUMN D_CONTENT.content_kind_id IS 'コンテンツ区分 (1:ファイル, 2:URL, ・・・)';
COMMENT ON COLUMN D_CONTENT.content_playtime IS 'コンテンツ再生時間（秒）';
COMMENT ON COLUMN D_CONTENT.content_order IS 'コンテンツ順';
COMMENT ON COLUMN D_CONTENT.content_data_1 IS 'コンテンツデータ1';
COMMENT ON COLUMN D_CONTENT.content_data_2 IS 'コンテンツデータ2';
COMMENT ON COLUMN D_CONTENT.content_data_3 IS 'コンテンツデータ3';
COMMENT ON COLUMN D_CONTENT.content_data_4 IS 'コンテンツデータ4';
COMMENT ON COLUMN D_CONTENT.content_data_5 IS 'コンテンツデータ5';
CREATE TABLE D_OPERATIONLOG(
	operationlog_id	serial		Not Null		,
	client_id	bigint		Not Null		,
	client_name	text		Not Null		,
	user_id	bigint		Not Null		,
	user_name	text		Not Null		,
	operation	text		Not Null		,
	operation_detail	text		Not Null		,
	operation_datetime	timestamp		Not Null		,
	operation_result	int		Not Null		
);

COMMENT ON COLUMN D_OPERATIONLOG.operationlog_id IS '操作ログID';
COMMENT ON COLUMN D_OPERATIONLOG.client_id IS 'クライアントID';
COMMENT ON COLUMN D_OPERATIONLOG.client_name IS 'クライアント名';
COMMENT ON COLUMN D_OPERATIONLOG.user_id IS 'ユーザID';
COMMENT ON COLUMN D_OPERATIONLOG.user_name IS 'ユーザ名';
COMMENT ON COLUMN D_OPERATIONLOG.operation IS '操作';
COMMENT ON COLUMN D_OPERATIONLOG.operation_detail IS '操作詳細（未使用）';
COMMENT ON COLUMN D_OPERATIONLOG.operation_datetime IS '操作日時';
COMMENT ON COLUMN D_OPERATIONLOG.operation_result IS '操作結果';
CREATE TABLE M_SYSTEM_CONFIG(
	config_key	text		Not Null		,
	config_value	text		Not Null		,
	CONSTRAINT M_SYSTEM_CONFIG_PK1 PRIMARY KEY (config_key)
);

COMMENT ON COLUMN M_SYSTEM_CONFIG.config_key IS 'キー';
COMMENT ON COLUMN M_SYSTEM_CONFIG.config_value IS '値';

